package WebGUI::i18n::Dutch::Form_Username;
use utf8;
our $I18N = {
  'username' => {
    'lastUpdated' => '1276684331',
    'message' => 'Gebruikersnaam'
  },
  'username in use' => {
    'lastUpdated' => '1268229001',
    'message' => 'Sorry, deze gebruikersnaam is al in gebruik door een andere gebruiker van deze site.'
  }
}
;

1;
